==> haskell-tls-1.5.5-9-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-tls.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 tls
version:              1.5.5
visibility:           public
id:                   tls-1.5.5-AulRCdVq9QDVlUyYU6EYJ
key:                  tls-1.5.5-AulRCdVq9QDVlUyYU6EYJ
license:              BSD-3-Clause
copyright:            Vincent Hanquez <vincent@snarc.org>
maintainer:           Vincent Hanquez <vincent@snarc.org>
author:               Vincent Hanquez <vincent@snarc.org>
stability:            experimental
homepage:             http://github.com/vincenthz/hs-tls
synopsis:             TLS/SSL protocol native implementation (Server and Client)
description:
    Native Haskell TLS and SSL protocol implementation for server and client.

    This provides a high-level implementation of a sensitive security protocol,
    eliminating a common set of security issues through the use of the advanced
    type system, high level constructions and common Haskell features.

    Currently implement the SSL3.0, TLS1.0, TLS1.1, TLS1.2 and TLS 1.3 protocol,
    and support RSA and Ephemeral (Elliptic curve and regular) Diffie Hellman key exchanges,
    and many extensions.

    Some debug tools linked with tls, are available through the
    <http://hackage.haskell.org/package/tls-debug/>.

category:             Network
abi:                  283618370fd757b4dc0153fdaa6d76d6
exposed:              True
exposed-modules:
    Network.TLS Network.TLS.Cipher Network.TLS.Compression
    Network.TLS.Extra Network.TLS.Extra.Cipher Network.TLS.Extra.FFDHE
    Network.TLS.Internal Network.TLS.QUIC

hidden-modules:
    Network.TLS.Cap Network.TLS.Struct Network.TLS.Struct13
    Network.TLS.Core Network.TLS.Context Network.TLS.Context.Internal
    Network.TLS.Credentials Network.TLS.Backend Network.TLS.Crypto
    Network.TLS.Crypto.DH Network.TLS.Crypto.IES
    Network.TLS.Crypto.Types Network.TLS.ErrT Network.TLS.Extension
    Network.TLS.Handshake Network.TLS.Handshake.Certificate
    Network.TLS.Handshake.Client Network.TLS.Handshake.Common
    Network.TLS.Handshake.Common13 Network.TLS.Handshake.Control
    Network.TLS.Handshake.Key Network.TLS.Handshake.Process
    Network.TLS.Handshake.Random Network.TLS.Handshake.Server
    Network.TLS.Handshake.Signature Network.TLS.Handshake.State
    Network.TLS.Handshake.State13 Network.TLS.Hooks Network.TLS.IO
    Network.TLS.Imports Network.TLS.KeySchedule Network.TLS.MAC
    Network.TLS.Measurement Network.TLS.Packet Network.TLS.Packet13
    Network.TLS.Parameters Network.TLS.PostHandshake Network.TLS.Record
    Network.TLS.Record.Disengage Network.TLS.Record.Engage
    Network.TLS.Record.Layer Network.TLS.Record.Reading
    Network.TLS.Record.Writing Network.TLS.Record.State
    Network.TLS.Record.Types Network.TLS.RNG Network.TLS.State
    Network.TLS.Session Network.TLS.Sending Network.TLS.Receiving
    Network.TLS.Util Network.TLS.Util.ASN1
    Network.TLS.Util.Serialization Network.TLS.Types Network.TLS.Wire
    Network.TLS.X509

import-dirs:          /usr/lib/ghc-8.10.4/site-local/tls-1.5.5
library-dirs:         /usr/lib/ghc-8.10.4/site-local/tls-1.5.5
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.4/tls-1.5.5
hs-libraries:         HStls-1.5.5-AulRCdVq9QDVlUyYU6EYJ
depends:
    asn1-encoding-0.9.6-KXGRsENgKkFF67rFrOnkbq
    asn1-types-0.3.4-G0yA25cpmUr7wLqoORcmTw
    async-2.2.3-bRJqoep3gj749cy8sss28 base-4.14.1.0
    bytestring-0.10.12.0 cereal-0.5.8.1-GAgNOTi0dTnED5BVJ0WdTc
    cryptonite-0.28-AlwGG8Ft8GF7C21jBzpVb
    data-default-class-0.1.2.0-56BXPST0gStFZdhRwxhsn8
    hourglass-0.2.12-DOStu5CdxhGBDzq0dGP6M8
    memory-0.15.0-E8yvrlcxsw5JtBytoHmuPe mtl-2.2.2
    network-3.1.2.1-8iRcwiFRMIG5nEfnXcFosV transformers-0.5.6.2
    x509-1.7.5-6J7ILvuTvXkJtjHKMeCJDH
    x509-store-1.6.7-2HQA3SoUHQDneauvggSfc
    x509-validation-1.6.11-LR3ASBpvTuD5IcUTjZaWzt

haddock-interfaces:   /usr/share/doc/haskell-tls/html/tls.haddock
haddock-html:         /usr/share/doc/haskell-tls/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-tls-1.5.5-12-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-tls.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 tls
version:              1.5.5
visibility:           public
id:                   tls-1.5.5-9dYpeHxt5A072qsBOd2az9
key:                  tls-1.5.5-9dYpeHxt5A072qsBOd2az9
license:              BSD-3-Clause
copyright:            Vincent Hanquez <vincent@snarc.org>
maintainer:           Vincent Hanquez <vincent@snarc.org>
author:               Vincent Hanquez <vincent@snarc.org>
stability:            experimental
homepage:             http://github.com/vincenthz/hs-tls
synopsis:             TLS/SSL protocol native implementation (Server and Client)
description:
    Native Haskell TLS and SSL protocol implementation for server and client.

    This provides a high-level implementation of a sensitive security protocol,
    eliminating a common set of security issues through the use of the advanced
    type system, high level constructions and common Haskell features.

    Currently implement the SSL3.0, TLS1.0, TLS1.1, TLS1.2 and TLS 1.3 protocol,
    and support RSA and Ephemeral (Elliptic curve and regular) Diffie Hellman key exchanges,
    and many extensions.

    Some debug tools linked with tls, are available through the
    <http://hackage.haskell.org/package/tls-debug/>.

category:             Network
abi:                  fdac7605c7022fe3699d4e58d94c2056
exposed:              True
exposed-modules:
    Network.TLS Network.TLS.Cipher Network.TLS.Compression
    Network.TLS.Extra Network.TLS.Extra.Cipher Network.TLS.Extra.FFDHE
    Network.TLS.Internal Network.TLS.QUIC

hidden-modules:
    Network.TLS.Cap Network.TLS.Struct Network.TLS.Struct13
    Network.TLS.Core Network.TLS.Context Network.TLS.Context.Internal
    Network.TLS.Credentials Network.TLS.Backend Network.TLS.Crypto
    Network.TLS.Crypto.DH Network.TLS.Crypto.IES
    Network.TLS.Crypto.Types Network.TLS.ErrT Network.TLS.Extension
    Network.TLS.Handshake Network.TLS.Handshake.Certificate
    Network.TLS.Handshake.Client Network.TLS.Handshake.Common
    Network.TLS.Handshake.Common13 Network.TLS.Handshake.Control
    Network.TLS.Handshake.Key Network.TLS.Handshake.Process
    Network.TLS.Handshake.Random Network.TLS.Handshake.Server
    Network.TLS.Handshake.Signature Network.TLS.Handshake.State
    Network.TLS.Handshake.State13 Network.TLS.Hooks Network.TLS.IO
    Network.TLS.Imports Network.TLS.KeySchedule Network.TLS.MAC
    Network.TLS.Measurement Network.TLS.Packet Network.TLS.Packet13
    Network.TLS.Parameters Network.TLS.PostHandshake Network.TLS.Record
    Network.TLS.Record.Disengage Network.TLS.Record.Engage
    Network.TLS.Record.Layer Network.TLS.Record.Reading
    Network.TLS.Record.Writing Network.TLS.Record.State
    Network.TLS.Record.Types Network.TLS.RNG Network.TLS.State
    Network.TLS.Session Network.TLS.Sending Network.TLS.Receiving
    Network.TLS.Util Network.TLS.Util.ASN1
    Network.TLS.Util.Serialization Network.TLS.Types Network.TLS.Wire
    Network.TLS.X509

import-dirs:          /usr/lib/ghc-8.10.4/site-local/tls-1.5.5
library-dirs:         /usr/lib/ghc-8.10.4/site-local/tls-1.5.5
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.4/tls-1.5.5
hs-libraries:         HStls-1.5.5-9dYpeHxt5A072qsBOd2az9
depends:
    asn1-encoding-0.9.6-5Rvqfn4QWoFGZQOG8EE1Kn
    asn1-types-0.3.4-4LRSMn1h6DPFsUCpmEVd55
    async-2.2.3-CMZHeJLKewc9LWcCGUabND base-4.14.1.0
    bytestring-0.10.12.0 cereal-0.5.8.1-GAgNOTi0dTnED5BVJ0WdTc
    cryptonite-0.28-APW4ixVZpxwDI6Btd1fI8B
    data-default-class-0.1.2.0-56BXPST0gStFZdhRwxhsn8
    hourglass-0.2.12-FSTVkDwVCbi4OvLMOTHoqw
    memory-0.15.0-E8yvrlcxsw5JtBytoHmuPe mtl-2.2.2
    network-3.1.2.1-3ek0iWyW48M1qyKNB0q4GG transformers-0.5.6.2
    x509-1.7.5-IAeX1Rqig2k7ALC6xoKaCD
    x509-store-1.6.7-BPPEctqwrRhHsQPIMzuf2j
    x509-validation-1.6.11-3sIHv6gGptL4fjsYC1wVyf

haddock-interfaces:   /usr/share/doc/haskell-tls/html/tls.haddock
haddock-html:         /usr/share/doc/haskell-tls/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
